@@ -1,10 +1,12 @@
 from lxml import etree
 
+from spei.resources import Respuesta
+
 SOAP_NS = 'http://schemas.xmlsoap.org/soap/envelope/'
 PRAXIS_NS = 'http://www.praxis.com.mx/'
 
 
-class Respuesta(object):
+class RespuestaElement(object):
     def __new__(cls, element):
         respuesta = etree.Element(
             etree.QName(PRAXIS_NS, 'respuesta'),
@@ -19,14 +21,14 @@ class Respuesta(object):
         return respuesta
 
 
-class Body(object):
+class BodyElement(object):
     def __new__(cls, respuesta):
         body = etree.Element(etree.QName(SOAP_NS, 'Body'))
         body.append(respuesta)
         return body
 
 
-class Envelope(object):
+class EnvelopeElement(object):
     def __new__(cls, body):
         etree.register_namespace('S', SOAP_NS)
         envelope = etree.Element(etree.QName(SOAP_NS, 'Envelope'))
@@ -35,8 +37,8 @@ class Envelope(object):
 
 
 class RespuestaRequest(object):
-    def __new__(cls, mensaje, as_string=True):
-        envelope = Respuesta(mensaje.build_xml())
+    def __new__(cls, mensaje: Respuesta, as_string=True):
+        envelope = RespuestaElement(mensaje.build_xml())
         if not as_string:
             return envelope
         return etree.tostring(envelope, xml_declaration=True)
